summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/DotNetOpenAuth/DotNetOpenAuth.csproj6
-rw-r--r--src/DotNetOpenAuth/OAuthWrap/ChannelElements/OAuthWrapAuthorizationServerChannel.cs2
-rw-r--r--src/DotNetOpenAuth/OAuthWrap/ChannelElements/WebServerVerificationCodeBindingElement.cs (renamed from src/DotNetOpenAuth/OAuthWrap/ChannelElements/WebAppVerificationCodeBindingElement.cs)6
-rw-r--r--src/DotNetOpenAuth/OAuthWrap/WebServerAuthorizationServer.cs (renamed from src/DotNetOpenAuth/OAuthWrap/WebAppAuthorizationServer.cs)6
-rw-r--r--src/DotNetOpenAuth/OAuthWrap/WebServerClient.cs (renamed from src/DotNetOpenAuth/OAuthWrap/WebAppClient.cs)6
5 files changed, 13 insertions, 13 deletions
diff --git a/src/DotNetOpenAuth/DotNetOpenAuth.csproj b/src/DotNetOpenAuth/DotNetOpenAuth.csproj
index ba776b6..543a725 100644
--- a/src/DotNetOpenAuth/DotNetOpenAuth.csproj
+++ b/src/DotNetOpenAuth/DotNetOpenAuth.csproj
@@ -322,7 +322,7 @@ http://opensource.org/licenses/ms-pl.html
<Compile Include="OAuthWrap\ChannelElements\DataBag.cs" />
<Compile Include="OAuthWrap\ChannelElements\TimestampEncoder.cs" />
<Compile Include="OAuthWrap\ChannelElements\VerificationCode.cs" />
- <Compile Include="OAuthWrap\ChannelElements\WebAppVerificationCodeBindingElement.cs" />
+ <Compile Include="OAuthWrap\ChannelElements\WebServerVerificationCodeBindingElement.cs" />
<Compile Include="OAuthWrap\ChannelElements\AuthServerAllFlowsBindingElement.cs" />
<Compile Include="OAuthWrap\IAccessTokenAnalyzer.cs" />
<Compile Include="OAuthWrap\IAuthorizationServer.cs" />
@@ -352,7 +352,7 @@ http://opensource.org/licenses/ms-pl.html
<Compile Include="OAuthWrap\ResourceServer.cs" />
<Compile Include="OAuthWrap\StandardAccessTokenAnalyzer.cs" />
<Compile Include="OAuthWrap\UserAgentClient.cs" />
- <Compile Include="OAuthWrap\WebAppAuthorizationServer.cs" />
+ <Compile Include="OAuthWrap\WebServerAuthorizationServer.cs" />
<Compile Include="OAuthWrap\WrapUtilities.cs" />
<Compile Include="OAuth\ChannelElements\ICombinedOpenIdProviderTokenManager.cs" />
<Compile Include="OAuth\ChannelElements\IConsumerDescription.cs" />
@@ -657,7 +657,7 @@ http://opensource.org/licenses/ms-pl.html
<DependentUpon>OAuthWrapStrings.resx</DependentUpon>
</Compile>
<Compile Include="OAuthWrap\AuthorizationServerDescription.cs" />
- <Compile Include="OAuthWrap\WebAppClient.cs" />
+ <Compile Include="OAuthWrap\WebServerClient.cs" />
<Compile Include="Util.cs" />
<Compile Include="OAuth\Protocol.cs" />
<Compile Include="OAuth\ServiceProvider.cs" />
diff --git a/src/DotNetOpenAuth/OAuthWrap/ChannelElements/OAuthWrapAuthorizationServerChannel.cs b/src/DotNetOpenAuth/OAuthWrap/ChannelElements/OAuthWrapAuthorizationServerChannel.cs
index 4b7b472..e6ddad1 100644
--- a/src/DotNetOpenAuth/OAuthWrap/ChannelElements/OAuthWrapAuthorizationServerChannel.cs
+++ b/src/DotNetOpenAuth/OAuthWrap/ChannelElements/OAuthWrapAuthorizationServerChannel.cs
@@ -177,7 +177,7 @@ namespace DotNetOpenAuth.OAuthWrap.ChannelElements {
if (authorizationServer != null) {
bindingElements.Add(new AuthServerAllFlowsBindingElement());
- bindingElements.Add(new WebAppVerificationCodeBindingElement());
+ bindingElements.Add(new WebServerVerificationCodeBindingElement());
bindingElements.Add(new AccessRequestBindingElement());
}
diff --git a/src/DotNetOpenAuth/OAuthWrap/ChannelElements/WebAppVerificationCodeBindingElement.cs b/src/DotNetOpenAuth/OAuthWrap/ChannelElements/WebServerVerificationCodeBindingElement.cs
index 585e02f..2a5bbd0 100644
--- a/src/DotNetOpenAuth/OAuthWrap/ChannelElements/WebAppVerificationCodeBindingElement.cs
+++ b/src/DotNetOpenAuth/OAuthWrap/ChannelElements/WebServerVerificationCodeBindingElement.cs
@@ -17,11 +17,11 @@ namespace DotNetOpenAuth.OAuthWrap.ChannelElements {
/// A binding element for OAuth 2.0 authorization servers that create/verify
/// issued verification codes as part of obtaining access/refresh tokens.
/// </summary>
- internal class WebAppVerificationCodeBindingElement : AuthServerBindingElementBase {
+ internal class WebServerVerificationCodeBindingElement : AuthServerBindingElementBase {
/// <summary>
/// Initializes a new instance of the <see cref="WebAppVerificationCodeBindingElement"/> class.
/// </summary>
- internal WebAppVerificationCodeBindingElement() {
+ internal WebServerVerificationCodeBindingElement() {
}
/// <summary>
@@ -17,11 +17,11 @@ namespace DotNetOpenAuth.OAuthWrap.ChannelElements {
/// <summary>
- /// Initializes a new instance of the <see cref="WebAppVerificationCodeBindingElement"/> class.
+ /// Initializes a new instance of the <see cref="WebServerVerificationCodeBindingElement"/> class.
/// </summary>
diff --git a/src/DotNetOpenAuth/OAuthWrap/WebAppAuthorizationServer.cs b/src/DotNetOpenAuth/OAuthWrap/WebServerAuthorizationServer.cs
index b4efb4f..5461e4c 100644
--- a/src/DotNetOpenAuth/OAuthWrap/WebAppAuthorizationServer.cs
+++ b/src/DotNetOpenAuth/OAuthWrap/WebServerAuthorizationServer.cs
@@ -15,12 +15,12 @@ namespace DotNetOpenAuth.OAuthWrap {
using DotNetOpenAuth.OAuthWrap.ChannelElements;
using DotNetOpenAuth.OAuthWrap.Messages;
- public class WebAppAuthorizationServer : AuthorizationServerBase {
+ public class WebServerAuthorizationServer : AuthorizationServerBase {
/// <summary>
/// Initializes a new instance of the <see cref="WebAppAuthorizationServer"/> class.
/// </summary>
/// <param name="authorizationServer">The authorization server.</param>
- public WebAppAuthorizationServer(IAuthorizationServer authorizationServer)
+ public WebServerAuthorizationServer(IAuthorizationServer authorizationServer)
: base(authorizationServer) {
Contract.Requires<ArgumentNullException>(authorizationServer != null, "authorizationServer");
}
@@ -15,12 +15,12 @@ namespace DotNetOpenAuth.OAuthWrap {
/// <summary>
- /// Initializes a new instance of the <see cref="WebAppAuthorizationServer"/> class.
+ /// Initializes a new instance of the <see cref="WebServerAuthorizationServer"/> class.
/// </summary>
/// <param name="authorizationServer">The authorization server.</param>
diff --git a/src/DotNetOpenAuth/OAuthWrap/WebAppClient.cs b/src/DotNetOpenAuth/OAuthWrap/WebServerClient.cs
index 3e10da3..977fddb 100644
--- a/src/DotNetOpenAuth/OAuthWrap/WebAppClient.cs
+++ b/src/DotNetOpenAuth/OAuthWrap/WebServerClient.cs
@@ -18,12 +18,12 @@ namespace DotNetOpenAuth.OAuthWrap {
/// <summary>
/// An OAuth WRAP consumer designed for web applications.
/// </summary>
- public class WebAppClient : ClientBase {
+ public class WebServerClient : ClientBase {
/// <summary>
/// Initializes a new instance of the <see cref="WebAppClient"/> class.
/// </summary>
/// <param name="authorizationServer">The authorization server.</param>
- public WebAppClient(AuthorizationServerDescription authorizationServer)
+ public WebServerClient(AuthorizationServerDescription authorizationServer)
: base(authorizationServer) {
}
@@ -18,12 +18,12 @@ namespace DotNetOpenAuth.OAuthWrap {
/// <summary>
- /// Initializes a new instance of the <see cref="WebAppClient"/> class.
+ /// Initializes a new instance of the <see cref="WebServerClient"/> class.
/// </summary>
/// <param name="authorizationServer">The authorization server.</param>